# detect-installed [![NPM version](https://img.shields.io/npm/v/detect-installed.svg?style=flat)](https://www.npmjs.com/package/detect-installed) [![NPM downloads](https://img.shields.io/npm/dm/detect-installed.svg?style=flat)](https://npmjs.org/package/detect-installed) [![npm total downloads][downloads-img]][downloads-url]

> Checks that given package is installed globally or locally.

[![code climate][codeclimate-img]][codeclimate-url] 
[![standard code style][standard-img]][standard-url] 
[![linux build status][travis-img]][travis-url] 
[![windows build status][appveyor-img]][appveyor-url] 
[![coverage status][coveralls-img]][coveralls-url] 
[![dependency status][david-img]][david-url]

You might also be interested in [get-installed-path](https://github.com/tunnckocore/get-installed-path#readme).

## Table of Contents
- [Install](#install)
- [Usage](#usage)
- [API](#api)
  * [detectInstalled](#detectinstalled)
  * [.sync](#sync)
- [Related](#related)
- [Contributing](#contributing)
- [Building docs](#building-docs)
- [Running tests](#running-tests)
- [Author](#author)
- [License](#license)

_(TOC generated by [verb](https://github.com/verbose/verb) using [markdown-toc](https://github.com/jonschlinkert/markdown-toc))_

## Install
Install with [npm](https://www.npmjs.com/)

```
$ npm install detect-installed --save
```

or install using [yarn](https://yarnpkg.com)

```
$ yarn add detect-installed
```

## Usage
> For more use-cases see the [tests](test.js)

```js
const detectInstalled = require('detect-installed')
```

## API

### [detectInstalled](index.js#L60)
> Detect if some package `name`is installed globally or locally. By default checks if it exists in globally installed modules, using [global-modules][]. Pass `opts.local` to check if it exists in locally installed modules or in `opts.cwd` dir.

**Params**

* `name` **{String}**: package name    
* `opts` **{Object}**: pass `opts.local` to check locally    
* `returns` **{Promise}**: always resolved promise, never rejected  

**Example**

```js
const detectInstalled = require('detect-installed')

detectInstalled('npm').then((exists) => {
  console.log(exists) // => true
})

detectInstalled('foo-bar-barwerwlekrjw').then((exists) => {
  console.log(exists) // => false
})

detectInstalled('npm', {
  local: true
}).then((exists) => {
  console.log(exists) // => false
})

detectInstalled('global-modules', {
  local: true
}).then((exists) => {
  console.log(exists) // => true
})

// If you are using it for some sub-directory
// pass `opts.cwd` to be where the `node_modules`
// folder is.
process.chidr('foo-bar-baz')
detectInstalled('global-modules', {
  local: true,
  cwd: '../'
}).then((exists) => console.log(exists)) // => true
```

### [.sync](index.js#L86)
> Synchronously check if package `name` exists as locally or globally installed modules.

**Params**

* `name` **{String}**: package name    
* `opts` **{Object}**: pass `opts.local` to check locally    
* `returns` **{Boolean}**: false, if error or not exists globally/locally  

**Example**

```js
const detectInstalled = require('detect-installed')

const exists = detectInstalled.sync('npm') // => true
const result = detectInstalled.sync('global-modules', { local: true }) // => true
```

## Related
- [always-done](https://www.npmjs.com/package/always-done): Handle completion and errors with elegance! Support for streams, callbacks, promises, child processes, async/await and sync functions. A drop-in replacement… [more](https://github.com/hybridables/always-done#readme) | [homepage](https://github.com/hybridables/always-done#readme "Handle completion and errors with elegance! Support for streams, callbacks, promises, child processes, async/await and sync functions. A drop-in replacement for [async-done][] - pass 100% of its tests plus more")
- [get-installed-path](https://www.npmjs.com/package/get-installed-path): Get locally or globally installation path of given package name | [homepage](https://github.com/tunnckocore/get-installed-path#readme "Get locally or globally installation path of given package name")
- [global-modules](https://www.npmjs.com/package/global-modules): The directory used by npm for globally installed npm modules. | [homepage](https://github.com/jonschlinkert/global-modules "The directory used by npm for globally installed npm modules.")
- [is-installed](https://www.npmjs.com/package/is-installed): Checks that given package is installed on the system - globally or locally. | [homepage](https://github.com/tunnckoCore/is-installed#readme "Checks that given package is installed on the system - globally or locally.")
- [minibase](https://www.npmjs.com/package/minibase): Minimalist alternative for Base. Build complex APIs with small units called plugins. Works well with most of the already existing… [more](https://github.com/node-minibase/minibase#readme) | [homepage](https://github.com/node-minibase/minibase#readme "Minimalist alternative for Base. Build complex APIs with small units called plugins. Works well with most of the already existing [base][] plugins.")
- [try-catch-core](https://www.npmjs.com/package/try-catch-core): Low-level package to handle completion and errors of sync or asynchronous functions, using [once][] and [dezalgo][] libs. Useful for and… [more](https://github.com/hybridables/try-catch-core#readme) | [homepage](https://github.com/hybridables/try-catch-core#readme "Low-level package to handle completion and errors of sync or asynchronous functions, using [once][] and [dezalgo][] libs. Useful for and used in higher-level libs such as [always-done][] to handle completion of anything.")

## Contributing
Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/tunnckoCore/detect-installed/issues/new).  
Please read the [contributing guidelines](CONTRIBUTING.md) for advice on opening issues, pull requests, and coding standards.  
If you need some help and can spent some cash, feel free to [contact me at CodeMentor.io](https://www.codementor.io/tunnckocore?utm_source=github&utm_medium=button&utm_term=tunnckocore&utm_campaign=github) too.

**In short:** If you want to contribute to that project, please follow these things

1. Please DO NOT edit [README.md](README.md), [CHANGELOG.md](CHANGELOG.md) and [.verb.md](.verb.md) files. See ["Building docs"](#building-docs) section.
2. Ensure anything is okey by installing the dependencies and run the tests. See ["Running tests"](#running-tests) section.
3. Always use `npm run commit` to commit changes instead of `git commit`, because it is interactive and user-friendly. It uses [commitizen][] behind the scenes, which follows Conventional Changelog idealogy.
4. Do NOT bump the version in package.json. For that we use `npm run release`, which is [standard-version][] and follows Conventional Changelog idealogy.

Thanks a lot! :)

## Building docs
Documentation and that readme is generated using [verb-generate-readme][], which is a [verb][] generator, so you need to install both of them and then run `verb` command like that

```
$ npm install verbose/verb#dev verb-generate-readme --global && verb
```

_Please don't edit the README directly. Any changes to the readme must be made in [.verb.md](.verb.md)._

## Running tests
Clone repository and run the following in that cloned directory

```
$ npm install && npm test
```

## Author
**Charlike Mike Reagent**

+ [github/tunnckoCore](https://github.com/tunnckoCore)
+ [twitter/tunnckoCore](http://twitter.com/tunnckoCore)
+ [codementor/tunnckoCore](https://codementor.io/tunnckoCore)

## License
Copyright © 2016, [Charlike Mike Reagent](http://i.am.charlike.online). Released under the [MIT license](LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.2.0, on December 11, 2016._  
_Project scaffolded using [charlike][] cli._

[always-done]: https://github.com/hybridables/always-done
[async-done]: https://github.com/gulpjs/async-done
[base]: https://github.com/node-base/base
[charlike]: https://github.com/tunnckocore/charlike
[commitizen]: https://github.com/commitizen/cz-cli
[dezalgo]: https://github.com/npm/dezalgo
[once]: https://github.com/isaacs/once
[standard-version]: https://github.com/conventional-changelog/standard-version
[verb-generate-readme]: https://github.com/verbose/verb-generate-readme
[verb]: https://github.com/verbose/verb

[downloads-url]: https://www.npmjs.com/package/detect-installed
[downloads-img]: https://img.shields.io/npm/dt/detect-installed.svg

[codeclimate-url]: https://codeclimate.com/github/tunnckoCore/detect-installed
[codeclimate-img]: https://img.shields.io/codeclimate/github/tunnckoCore/detect-installed.svg

[travis-url]: https://travis-ci.org/tunnckoCore/detect-installed
[travis-img]: https://img.shields.io/travis/tunnckoCore/detect-installed/master.svg?label=linux

[appveyor-url]: https://ci.appveyor.com/project/tunnckoCore/detect-installed
[appveyor-img]: https://img.shields.io/appveyor/ci/tunnckoCore/detect-installed/master.svg?label=windows

[coveralls-url]: https://coveralls.io/r/tunnckoCore/detect-installed
[coveralls-img]: https://img.shields.io/coveralls/tunnckoCore/detect-installed.svg

[david-url]: https://david-dm.org/tunnckoCore/detect-installed
[david-img]: https://img.shields.io/david/tunnckoCore/detect-installed.svg

[standard-url]: https://github.com/feross/standard
[standard-img]: https://img.shields.io/badge/code%20style-standard-brightgreen.svg

[global-modules]: https://github.com/jonschlinkert/global-modules